@@ -52,10 +52,14 @@ maplist = {
     'CopySourceIfUnmodifiedSince': 'x-cos-copy-source-If-Unmodified-Since',
     'VersionId': 'versionId',
     'ServerSideEncryption': 'x-cos-server-side-encryption',
+    'SSEKMSKeyId': 'x-cos-server-side-encryption-cos-kms-key-id',
+    'SSEKMSContext': 'x-cos-server-side-encryption-context',
     'SSECustomerAlgorithm': 'x-cos-server-side-encryption-customer-algorithm',
     'SSECustomerKey': 'x-cos-server-side-encryption-customer-key',
     'SSECustomerKeyMD5': 'x-cos-server-side-encryption-customer-key-MD5',
-    'SSEKMSKeyId': 'x-cos-server-side-encryption-cos-kms-key-id',
+    'CopySourceSSECustomerAlgorithm': 'x-cos-copy-source-server-side-encryption-customer-algorithm',
+    'CopySourceSSECustomerKey': 'x-cos-copy-source-server-side-encryption-customer-key',
+    'CopySourceSSECustomerKeyMD5': 'x-cos-copy-source-server-side-encryption-customer-key-MD5',
     'Referer': 'Referer',
     'PicOperations': 'Pic-Operations',
     'TrafficLimit': 'x-cos-traffic-limit',
@@ -217,14 +221,18 @@ def format_values(data):
 
 
 def format_endpoint(endpoint, region, module=u'cos.'):
-    """格式化终端域名"""
-    if not endpoint and not region:
+    # 客户使用全球加速域名时，只会传endpoint不会传region。此时这样endpointCi和region同时为None，就会报错。
+    if not endpoint and not region and module == u'cos.':
         raise CosClientError("Region or Endpoint is required not empty!")
-    if not endpoint:
+
+    """格式化终端域名"""
+    if endpoint:
+        return to_unicode(endpoint)
+    elif region:
         region = format_region(region, module)
         return u"{region}.myqcloud.com".format(region=region)
     else:
-        return to_unicode(endpoint)
+        return None
 
 
 def format_region(region, module=u'cos.'):
@@ -388,13 +396,26 @@ def format_dict(data, key_lst):
         return data
     for key in key_lst:
         # 将dict转为list，保持一致
-        if key in data and (isinstance(data[key], dict) or isinstance(data[key], str)):
+        if key in data and (isinstance(data[key], dict) or isinstance(data[key], string_types)):
             lst = []
             lst.append(data[key])
             data[key] = lst
     return data
 
 
+def format_dict_or_list(data, key_lst):
+    """转换返回dict或list中的可重复字段为list"""
+    if not ((isinstance(data, list) or isinstance(data, dict)) and isinstance(key_lst, list)):
+        return data
+    if isinstance(data, dict):
+        return format_dict(data, key_lst)
+
+    for data_item in data:
+        format_dict(data_item, key_lst)
+
+    return data
+
+
 def decode_result(data, key_lst, multi_key_list):
     """decode结果中的字段"""
     for key in key_lst:
@@ -463,6 +484,8 @@ class CiDetectType():
     TERRORIST = 2
     POLITICS = 4
     ADS = 8
+    ILLEGAL = 16
+    ABUSE = 32
 
     @staticmethod
     def get_detect_type_str(DetectType):
@@ -482,6 +505,14 @@ class CiDetectType():
             if len(detect_type) > 0:
                 detect_type += ','
             detect_type += 'Ads'
+        if DetectType & CiDetectType.ILLEGAL > 0:
+            if len(detect_type) > 0:
+                detect_type += ','
+            detect_type += 'Illegal'
+        if DetectType & CiDetectType.ABUSE > 0:
+            if len(detect_type) > 0:
+                detect_type += ','
+            detect_type += 'Abuse'
 
         return detect_type
 
